#if HAVE_CONFIG_H
# include "config.h"
#endif

#include <libtasn1.h>

const asn1_static_node Test_tree_asn1_tab[] = {
  { "TEST_TREE", 536875024, NULL },
  { NULL, 1610612748, NULL },
  { "iso", 1073741825, "1"},
  { "identified-organization", 1073741825, "3"},
  { "dod", 1073741825, "6"},
  { "internet", 1073741825, "1"},
  { "security", 1073741825, "5"},
  { "mechanisms", 1073741825, "5"},
  { "pkix", 1073741825, "7"},
  { "id-mod", 1073741825, "0"},
  { "id-pkix1-implicit-88", 1, "2"},
  { "KrbError", 1610620933, NULL },
  { NULL, 1073746952, "30"},
  { "pvno", 536879107, NULL },
  { NULL, 4104, "0"},
  { "Checksum", 1610612741, NULL },
  { "checksum", 536879111, NULL },
  { NULL, 4104, "1"},
  { "CertTemplate", 1610612741, NULL },
  { "version", 1610637315, NULL },
  { NULL, 4104, "0"},
  { "issuer", 1610637314, "Name"},
  { NULL, 4104, "3"},
  { "validity", 536895491, NULL },
  { NULL, 4104, "4"},
  { "Name", 1610612754, NULL },
  { "rdnSequence", 2, "RDNSequence"},
  { "RDNSequence", 1073741826, "RelativeDistinguishedName"},
  { "RelativeDistinguishedName", 1612709903, NULL },
  { "MAX", 1074266122, "1"},
  { NULL, 2, "AttributeTypeAndValue"},
  { "AttributeTypeAndValue", 1610612741, NULL },
  { "type", 1073741826, "AttributeType"},
  { "value", 2, "AttributeValue"},
  { "AttributeType", 1073741836, NULL },
  { "AttributeValue", 1073741837, NULL },
  { "sequenceEmpty", 1610612741, NULL },
  { "int1", 1073741827, NULL },
  { "seq1", 1610620930, "Sequence_octetTest1"},
  { NULL, 4104, "1"},
  { "set1", 536879119, NULL },
  { NULL, 1073743880, "2"},
  { NULL, 3, NULL },
  { "IndefiniteLengthTest", 1610612741, NULL },
  { "seq1", 1610620930, "Sequence_octetTest1"},
  { NULL, 4104, "1"},
  { "set1", 1610612751, NULL },
  { NULL, 12, NULL },
  { "int1", 3, NULL },
  { "OidTest", 1610612741, NULL },
  { "oid3", 1610653708, NULL },
  { NULL, 1073741833, "id-Test"},
  { NULL, 4104, "3"},
  { "oid", 1610653708, NULL },
  { NULL, 1073741833, "id-anyTest2"},
  { NULL, 4104, "1"},
  { "oid2", 536911884, NULL },
  { NULL, 1073741833, "id-anyTest"},
  { NULL, 4104, "2"},
  { "OidAndTimeTest", 1610612741, NULL },
  { "set", 1610612751, NULL },
  { NULL, 3, NULL },
  { "oid", 1073741836, NULL },
  { "time2", 1082130449, NULL },
  { "bol", 1073741828, NULL },
  { "oct", 1073741831, NULL },
  { "bit", 1073758214, NULL },
  { "bol2", 1610645508, NULL },
  { NULL, 65545, NULL },
  { "enum", 1610907669, NULL },
  { NULL, 1073741833, "v1"},
  { "v1", 1073741825, "1"},
  { "v2", 1, "2"},
  { "any", 1610637325, NULL },
  { NULL, 4104, "1"},
  { "gen", 1073758235, NULL },
  { "time1", 16777233, NULL },
  { "SequenceTestTag", 1610612741, NULL },
  { "int1", 1610620931, NULL },
  { NULL, 2056, "2"},
  { "int2", 1610620931, NULL },
  { NULL, 4104, "3"},
  { "str1", 1610620959, NULL },
  { NULL, 4104, "1"},
  { "str2", 1073741856, NULL },
  { "str3", 536879136, NULL },
  { NULL, 2056, "2"},
  { "Sequence1", 1610612741, NULL },
  { "int1", 1610915843, NULL },
  { NULL, 1073741833, "v2"},
  { NULL, 1073745928, "0"},
  { "v1", 1073741825, "0"},
  { "v2", 1073741825, "1"},
  { "v3", 1, "2"},
  { "int2", 1073741827, NULL },
  { "seq", 1610612751, NULL },
  { NULL, 3, NULL },
  { "id", 1073741836, NULL },
  { "oct", 1073741831, NULL },
  { "any1", 541081613, NULL },
  { "id", 1, NULL },
  { "DHParameter", 1610612741, NULL },
  { "prime", 1073741827, NULL },
  { "base", 1073741827, NULL },
  { "privateValueLength", 16387, NULL },
  { "id-octetTest1", 1879048204, NULL },
  { NULL, 1073741825, "1"},
  { NULL, 1073741825, "2"},
  { NULL, 1073741825, "3"},
  { NULL, 1, "4"},
  { "Sequence_octetTest1", 1610612741, NULL },
  { "int", 16387, NULL },
  { "AnyTest2", 1610612754, NULL },
  { "str", 1073741831, NULL },
  { "int", 3, NULL },
  { "id-ic", 1879048204, NULL },
  { NULL, 1073741825, "2"},
  { NULL, 1, "5"},
  { "id-anyTest", 1879048204, NULL },
  { NULL, 1073741825, "id-ic"},
  { NULL, 1073741825, "29"},
  { NULL, 1, "1"},
  { "id-anyTest2", 1879048204, NULL },
  { NULL, 1073741825, "id-ic"},
  { NULL, 1073741825, "29"},
  { NULL, 1, "2"},
  { "anyTest2", 1073741827, NULL },
  { "VisibleString", 1610620935, NULL },
  { NULL, 4360, "26"},
  { "NumericString", 1610620935, NULL },
  { NULL, 4360, "18"},
  { "IA5String", 1610620935, NULL },
  { NULL, 4360, "22"},
  { "TeletexString", 1610620935, NULL },
  { NULL, 4360, "20"},
  { "PrintableString", 1610620935, NULL },
  { NULL, 4360, "19"},
  { "UniversalString", 1610620935, NULL },
  { NULL, 4360, "28"},
  { "BMPString", 1610620935, NULL },
  { NULL, 4360, "30"},
  { "UTF8String", 1610620935, NULL },
  { NULL, 4360, "12"},
  { "Test3", 1610612741, NULL },
  { "a", 1073741827, NULL },
  { "b", 536879106, "GeneralString2"},
  { NULL, 2056, "1"},
  { "GeneralString2", 1610620955, NULL },
  { NULL, 2056, "2"},
  { "X520LocalityName", 1610612754, NULL },
  { "teletexString", 1073741854, NULL },
  { "printableString", 1073741855, NULL },
  { "universalString", 1073741856, NULL },
  { "utf8String", 1073741858, NULL },
  { "bmpString", 33, NULL },
  { "id-Test", 805306380, NULL },
  { NULL, 1073741825, "1"},
  { NULL, 1073741825, "2"},
  { NULL, 1073741825, "29"},
  { NULL, 1, "2"},
  { NULL, 0, NULL }
};
